/*++
Copyright (c) 2006 Microsoft Corporation

Module Name:

    theory_arith_def.h

Abstract:

    <abstract>

Author:

    Leonardo de Moura (leonardo) 2008-04-22.

Revision History:

--*/
#ifndef THEORY_ARITH_DEF_H_
#define THEORY_ARITH_DEF_H_

#include "smt/theory_arith.h"
#include "smt/theory_arith_core.h"
#include "smt/theory_arith_aux.h"
#include "smt/theory_arith_inv.h"
#include "smt/theory_arith_pp.h"
#include "smt/theory_arith_int.h"
#include "smt/theory_arith_eq.h"
#include "smt/theory_arith_nl.h"

#endif /* THEORY_ARITH_DEF_H_ */

